OC.L10N.register(
    "settings",
    {
    "{actor} added you to group {group}" : "{actor} به گروه {group} افزودتان",
    "You added {user} to group {group}" : "{user} را به گروه {group} افزودید",
    "{actor} added {user} to group {group}" : "{actor} کاربر {user} را به گروه {group} افزود",
    "An administrator added you to group {group}" : "مدیری به گروه {group} افزودتان",
    "An administrator added {user} to group {group}" : "مدیری {user}  را به گروه {group} افزود",
    "{actor} removed you from group {group}" : "{actor} از گروه {group} برداشتتان",
    "You removed {user} from group {group}" : "{user} را از گروه {group} برداشتید",
    "{actor} removed {user} from group {group}" : "{actor} کاربر {user} را از گروه {group} برداشت",
    "An administrator removed you from group {group}" : "مدیری از گروه {group} برداشتتان",
    "An administrator removed {user} from group {group}" : "مدیری {user} را از گروه {group} برداشت",
    "Your <strong>group memberships</strong> were modified" : "<strong>عضویتتان در گروه</strong> تغییر یافت",
    "{actor} changed your password" : "{actor} گذرواژه‌تان را تغییر داد",
    "You changed your password" : "گذرواژه‌تان را تغییر دادید",
    "Your password was reset by an administrator" : "گذرواژه‌تان به دست مدیری بازنشانی شد",
    "Your password was reset" : "گذرواژه‌تان بازنشانی شد",
    "{actor} changed your email address" : "{actor} نشانی رایانامه‌تان را تغییر داد",
    "You changed your email address" : "نشانی رایانامه‌تان را تغییر دادید",
    "Your email address was changed by an administrator" : "نشانی رایانامه‌تان به دست مدیری عوض شد",
    "You created an app password for a session named \"{token}\"" : "You created an app password for a session named \"{token}\"",
    "An administrator created an app password for a session named \"{token}\"" : "An administrator created an app password for a session named \"{token}\"",
    "You deleted app password \"{token}\"" : "گذرواژهٔ کارهٔ «{token}» را حذف کردید",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "نام گذرواژهٔ کارهٔ «{token}» را به «{newToken}» تغییر دادید",
    "You granted filesystem access to app password \"{token}\"" : "دسترسی به سامانه‌پرونده را به گذرواژهٔ کارهٔ «{token}» اعطا کردید",
    "You revoked filesystem access from app password \"{token}\"" : "دسترسی به سامانه‌پرونده را از گذرواژهٔ کارهٔ «{token}» گرفتید",
    "Security" : "امنیت",
    "You successfully logged in using two-factor authentication (%1$s)" : "شما با موفقیت با استفاده از تأیید هویت دو عاملی وارد سیستم شدید(%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "تلاش برای ورود به سیستم با استفاده از تأیید هویت دو عاملی انجام نشد (%1$s)",
    "Remote wipe was started on %1$s" : "پاک کردن از راه دور شروع شد %1$s",
    "Remote wipe has finished on %1$s" : "پاک کردن از راه دور به پایان رسید%1$s",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>پسورد</strong> و یا  <strong>پست الکترونیک</strong> شما ویراش شد.",
    "Settings" : "تنظیمات",
    "Could not remove app." : "امکان حذف برنامه وجود ندارد.",
    "Could not update app." : "برنامه را نمی توان به روزرسانی کرد .",
    "Wrong password" : "رمز عبور اشتباه است",
    "Unable to change personal password" : "نمی‌توان گذرواژه شخصی را تغییر داد",
    "Saved" : "ذخیره شد",
    "Unable to change password" : "نمی‌توان رمز را تغییر داد",
    "Unable to change password. Password too long." : "Unable to change password. Password too long.",
    "Authentication error" : "خطا در اعتبار سنجی",
    "Wrong admin recovery password. Please check the password and try again." : "رمز مدیریتی بازیابی غلط است. لطفاً رمز را کنترل کرده و دوباره امتحان نمایید.",
    "Administrator documentation" : "مستندات مدیر",
    "User documentation" : "مستندات کاربر",
    "Nextcloud help overview" : "نمای کلی راهنمای نکست‌کلود",
    "Invalid SMTP password." : "گذرواژه SMTP نامعتبر است.",
    "Email setting test" : "تست تنظیم پست الکترونیک",
    "Well done, %s!" : "انجام شد،%s!",
    "If you received this email, the email configuration seems to be correct." : "اگر این پست الکترونیک را دریافت کردید ، پیکربندی ایمیل درست است.",
    "Email could not be sent. Check your mail server log" : "پست الکترونیک قابل ارسال نیست. ورود به سیستم سرور پست الکترونیک خود را بررسی کنید",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "ارسال پست الکترونیک با خطا مواجه شد، لطفاً تنظیمات خود را مورد بازبینی قرار دهید. (خطا:%s)",
    "Disabled accounts" : "حساب‌های غیرفعال",
    "Invalid mail address" : "آدرس ایمیل نامعتبر است",
    "Settings saved" : "تنظیمات ذخیره شد",
    "Unable to change full name" : "امکان تغییر نام کامل وجود ندارد",
    "Unable to change email address" : "تغییرات پست الکترونیک امکان‌پذیر نیست",
    "Unable to set invalid phone number" : "Unable to set invalid phone number",
    "Unable to set invalid website" : "Unable to set invalid website",
    "Some account data was invalid" : "Some account data was invalid",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "به منظور تأیید حساب توییتر خود ، توییت زیر را در توییتر قرار دهید (لطفاً آن را بدون هیچگونه فاصله بین خطوط ارسال کنید):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "برای تأیید وب سایت خود ، مطالب زیر را در ریشه وب خود در سایت ذخیره کنید:\n '.well-known/CloudIdVerificationCode.txt' \n(لطفاً اطمینان حاصل کنید که تمام متن در یک خط است):",
    "%1$s changed your password on %2$s." : "%1$s رمزعبور خود را تغییر داد به %2$s",
    "Your password on %s was changed." : "پسورد شما به %s تغییر یافت",
    "Your password on %s was reset by an administrator." : "رمز عبور شما توسط یک مدیر به %s تنظیم مجدد شد.",
    "Your password on %s was reset." : "Your password on %s was reset.",
    "Password for %1$s changed on %2$s" : "رمزعبور از %1$sبه %2$s تغییر یافت",
    "Password changed for %s" : "پسور به %s تغییر یافت",
    "If you did not request this, please contact an administrator." : "اگر این درخواست را نکردید ، با یک مدیر تماس بگیرید.",
    "Your email address on %s was changed." : "پست الکترونیک شما به %s تغییر یافت",
    "Your email address on %s was changed by an administrator." : "پست الکترونیک شما توط یک مدیر به %s  تنظیم مجدد شد.",
    "Email address for %1$s changed on %2$s" : "پست الکترونیک از %1$s به %2$s تغییر یافت.",
    "Email address changed for %s" : "پست الکترونیک به %s تغییر یافت",
    "The new email address is %s" : "آدرس پست الکترونیک جدید %s می باشد.",
    "Your %s account was created" : "حساب کاربری شما  %s ایجاد شد",
    "Welcome aboard" : "به داخل خوش آمدید",
    "Welcome aboard %s" : "به داخل خوش آمدید %s",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s به حساب کاربری خود خوش آمدید ،شما می توانید اضافه کنید ، محافظت و اطلاعات خود را اشتراک به بگذارید.",
    "Set your password" : "کلمه ی عبور خود را تنظیم کنید",
    "Go to %s" : "برو به %s",
    "Install Client" : "قسمت مشتری را نصب کنید",
    "Apps" : "برنامه ها",
    "Personal" : "شخصی",
    "Administration" : "مدیریت",
    "Users" : "کاربران",
    "Additional settings" : "تنظیمات اضافی",
    "Administration privileges" : "اجازه‌های مدیریتی",
    "Groupware" : "کار گروهی",
    "Overview" : "نمای کلّی",
    "Basic settings" : "تنظیمات پایه",
    "Sharing" : "اشتراک گذاری",
    "Availability" : "در دسترس بودن",
    "Calendar" : "تقویم",
    "Personal info" : "اطّلاعات شخصی",
    "Mobile & desktop" : "همراه و میزکار",
    "Artificial Intelligence" : "هوش مصنوعی",
    "Email server" : "سرور ایمیل",
    "Background jobs" : "کارهای پس‌زمینه",
    "Unlimited" : "نامحدود",
    "Verifying" : "تآیید کردن",
    "Verifying …" : "تأیید کردن…",
    "Verify" : "تأیید",
    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
    "Disabled" : "غیرفعال شده",
    "The old server-side-encryption format is enabled. We recommend disabling this." : "The old server-side-encryption format is enabled. We recommend disabling this.",
    "Logging level" : "سطح گزارش‌دهی",
    "The logging level is set to debug level. Use debug level only when you have a problem to diagnose, and then reset your log level to a less-verbose level as it outputs a lot of information, and can affect your server performance." : "سطح گزارش‌دهی روی حالت اشکال‌زدایی (debug) تنظیم شده است. از سطح اشکال‌زدایی تنها زمانی استفاده کنید که مشکلی برای تشخیص دارید، سپس سطح گزارش خود را به حالت کم‌حجم‌تری بازگردانید زیرا این حالت حجم زیادی از اطلاعات را خروجی می‌دهد و می‌تواند بر عملکرد نمونهٔ شما تأثیر منفی بگذارد.",
    "Logging level configured correctly." : "سطح گزارش‌دهی به درستی تنظیم شد.",
    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
    "Supported" : "پشتیبانی شده",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
    "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation.",
    "PHP configuration option \"output_buffering\" must be disabled" : "گزینه «output_buffering» تنظیمات پی‌اچ‌پی باید غیرفعال شود",
    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
    "Architecture" : "Architecture",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
    "Profile information" : "اطلاعات نمایه",
    "Nextcloud settings" : "تنظیمات نکست کلود",
    "Enable" : "فعال",
    "Machine translation" : "Machine translation",
    "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment.",
    "Image generation" : "Image generation",
    "Text processing" : "Text processing",
    "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task.",
    "Task:" : "Task:",
    "Here you can decide which group can access certain sections of the administration settings." : "Here you can decide which group can access certain sections of the administration settings.",
    "Unable to modify setting" : "Unable to modify setting",
    "None" : "هیچ‌کدام",
    "Allow apps to use the Share API" : "اجازه ی برنامه ها برای استفاده از API اشتراک گذاری",
    "Allow resharing" : "مجوز اشتراک گذاری مجدد",
    "Allow sharing with groups" : "اشتراک گذاری با گروه ها مجاز است",
    "Restrict users to only share with users in their groups" : "محدود کردن کاربران برای اشتراک‌گذاری تنها میان کاربران گروه خود",
    "Allow users to share via link and emails" : "Allow users to share via link and emails",
    "Allow public uploads" : "اجازه بارگذاری عمومی",
    "Always ask for a password" : "رمز عبور را همیشه بپرسید.",
    "Enforce password protection" : "اجبار برای محافظت توسط رمز عبور",
    "Enforce expiration date" : "اعمال تاریخ اتمام اشتراک گذاری",
    "Set default expiration date for shares to other servers" : "Set default expiration date for shares to other servers",
    "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Show disclaimer text on the public link upload page (only shown when the file list is hidden)",
    "This text will be shown on the public link upload page when the file list is hidden." : "این متن هنگام پنهان کردن لیست پرونده در صفحه بارگذاری پیوند عمومی نشان داده می شود.",
    "Default share permissions" : "مجوزهای اشتراکی پیش فرض",
    "Two-Factor Authentication" : "احراز هویت دو عاملی",
    "Enforce two-factor authentication" : "احراز هویت دو عاملی",
    "Limit to groups" : "محدود کردن به گروه‌ها",
    "Enforcement of two-factor authentication can be set for certain groups only." : "اجبار به احراز هویت دو عاملی فقط می‌تواند برای گروه‌هایی خاص تنظیم شود.",
    "Two-factor authentication is enforced for all members of the following groups." : "Two-factor authentication is enforced for all members of the following groups.",
    "Enforced groups" : "گروه‌های اجباری",
    "Two-factor authentication is not enforced for members of the following groups." : "Two-factor authentication is not enforced for members of the following groups.",
    "Excluded groups" : "گروه‌های مستثنی",
    "Save changes" : "ذخیرهٔ تغییرات",
    "Default" : "پیش‌فرض",
    "Update to {update}" : "به‌روز رسانی به {update} ",
    "Remove" : "برداشتن",
    "Featured" : "برگزیده",
    "This app is supported via your current Nextcloud subscription." : "این کاره از طریق اشتراک فعلی نکست کلودتان پشتیبانی می شود.",
    "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "برنامه‌های برگزیده توسط و در داخل جامعه توسعه داده می‌شوند. این برنامه‌ها، عملکردهای مرکزی را ارائه می‌دهند و برای استفاده نهایی آماده هستند.",
    "Learn more" : "بیشتر بدانید",
    "Disable all" : "از کار انداختن همه",
    "All apps are up-to-date." : "تمامی کاره‌ها به‌روزند.",
    "Icon" : "Icon",
    "Name" : "نام",
    "Version" : "نسخه",
    "Level" : "مرحله",
    "Actions" : "کنش‌ها",
    "Results from other categories" : "نتایج از دیگر دسته‌ها",
    "No apps found for your version" : "هیچ برنامه‌ای برای نسخه‌ی شما یافت نشد",
    "_%n app has an update available_::_%n apps have an update available_" : ["۱ کاره به‌روز رسانی دارد","%n کاره به‌روز رسانی دارند"],
    "_Update_::_Update all_" : ["به‌روز رسانی","به‌روز رسانی همه"],
    "Groups" : "گروه ها",
    "Group name" : "نام گروه",
    "Loading groups…" : "Loading groups…",
    "Loading" : "Loading",
    "Daemon" : "فرایندهای پس زمینه",
    "Type" : "نوع",
    "Confirm" : "تأیید",
    "Cancel" : "منصرف شدن",
    "Description" : "شرح",
    "View in store" : "نمایش در فروشگاه",
    "Visit website" : "سر زدن به پایگاه وب",
    "Admin documentation" : "مستندات مدیریتی",
    "Developer documentation" : "مستندات توسعه",
    "Details" : "جزییات",
    "All" : "همه",
    "Limit app usage to groups" : "محدودیت استفاده از برنامه به گروه‌ها",
    "No results" : "بدون نتیجه",
    "Update to {version}" : "به‌روز رسانی به {version}",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "امکان نصب این برنامه وجود ندارد، این پیش‌نیازها انجام نشده‌اند:",
    "Author" : "نویسنده",
    "Categories" : "دسته‌ها",
    "Resources" : "منابع",
    "Documentation" : "مستندسازی",
    "Interact" : "تعامل",
    "Report a bug" : "گزارش یک اشکال",
    "Request feature" : "درخواست ویژگی",
    "Ask questions or discuss" : "پرسش یا بحث",
    "Rate" : "رتبه‌بندی",
    "Changelog" : "تغییر",
    "Google Chrome for Android" : "کروم گوگل برای اندروید",
    "{productName} iOS app" : "کارهٔ iOS {productName}",
    "{productName} Android app" : "کارهٔ اندرویدی {productName}",
    "{productName} Talk for iOS" : "صحبت {productName} برای iOS",
    "{productName} Talk for Android" : "صحبت {productName} برای اندروید",
    "This session" : "این نشست",
    "Marked for remote wipe" : "علامت خورده برای زودون دوردست",
    "Device settings" : "تنظیمات افزاره",
    "Allow filesystem access" : "اجازهٔ دسترسی به سامانه‌پرونده",
    "Rename" : "تغییرنام",
    "Revoke" : "لغو",
    "Wipe device" : "حذف دستگاه",
    "Revoking this token might prevent the wiping of your device if it has not started the wipe yet." : "Revoking this token might prevent the wiping of your device if it has not started the wipe yet.",
    "Device" : "افزاره",
    "Last activity" : "آخرین فعّالیت",
    "Devices & sessions" : "دستگاه ها و نشست ها",
    "Web, desktop and mobile clients currently logged in to your account." : "لیست دستگاه ها و نشست های فعال وارد شده با اکانت شما",
    "Error while creating device token" : "هنگام ایجاد نشانه وسیله خطایی رخ داد",
    "App name" : "نام کاره",
    "Create new app password" : "ساختن رمزعبور برنامه جدید ",
    "Could not copy app password. Please copy it manually." : "نمی توان رمزعبور برنامه را کپی کرد. لطفاً آن را به صورت دستی کپی کنید.",
    "Login" : "ورود",
    "Password" : "گذرواژه",
    "Show QR code for mobile apps" : "نمایش کد QR برای برنامه های تلفن همراه",
    "Use system cron service to call the cron.php file every 5 minutes." : "برای تماس با پرونده cron.php هر 5 دقیقه یکبار از سرویس cron system استفاده کنید.",
    "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details." : "The PHP POSIX extension is required. See {linkstart}PHP documentation{linkend} for more details.",
    "Unable to update background job mode" : "ناتوان در به‌روز رسانی حالت کار پس‌زمینه",
    "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information." : "For the server to work properly, it's important to configure background jobs correctly. Cron is the recommended setting. Please see the documentation for more information.",
    "Last job execution ran {time}. Something seems wrong." : "آخرین کار در {time} اجرا شد. به نظر چیزی اشتباه است.",
    "Last job ran {relativeTime}." : "آخرین کار در {relativeTime} اجرا شد.",
    "Background job did not run yet!" : "هنوز کار پس‌زمینه‌ای اجار نشده!",
    "AJAX" : "ای‌جکس",
    "Webcron" : "وب‌کرون",
    "Cron (Recommended)" : "کرون (پیشنهادی)",
    "Unable to update profile default setting" : "ناتوان در به‌روز رسانی تنظیمات پیش‌گزیدهٔ نمایه",
    "Profile" : "نمایه",
    "Unable to update server side encryption config" : "Unable to update server side encryption config",
    "Server-side encryption" : "رمزگذاری سمت سرور",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "\"رمزگذاری سمت سرور\" امکان رمزگذاری پرونده های آپلود شده در این سرور را امکان پذیر می کند. که با محدودیت هایی مانند مجازات عملکرد همراه است ، بنابراین در صورت لزوم فعال کنید.",
    "Enable server-side encryption" : "فعال‌سازی رمزگذاری سمت-سرور",
    "No encryption module loaded, please enable an encryption module in the app menu." : "هیچ ماژول رمزگذاری‌ای بارگذاری نشده است، لطفا ماژول رمز‌گذاری را در منو برنامه فعال کنید.",
    "Select default encryption module:" : "انتخاب ماژول پیش‌فرض رمزگذاری:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}" : "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run {command}",
    "Enable encryption" : "فعال کردن رمزگذاری",
    "Please read carefully before activating server-side encryption:" : "Please read carefully before activating server-side encryption:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "پس از فعال سازی رمزگذاری ، تمام پرونده های بارگذاری شده از آن نقطه به سرور بارگیری می شوند و در حالت آماده به کار روی سرور رمزگذاری می شوند. غیرفعال کردن رمزگذاری در صورتی که ماژول رمزگذاری فعال از آن عملکرد پشتیبانی کند، در تاریخ بعد امکان پذیر است و کلیه پیش شرط ها (به عنوان مثال تنظیم کلید بازیابی) برآورده می شوند.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "رمزگذاری به تنهایی امنیت سیستم را تضمین نمی کند. لطفاً برای اطلاعات بیشتر درباره چگونگی عملکرد برنامه رمزگذاری و موارد استفاده از پشتیبانی ، به اسناد مراجعه کنید.",
    "Be aware that encryption always increases the file size." : "توجه داشته باشید که همواره رمزگذاری حجم فایل را افزایش خواهد داد.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "همیشه خوب است که از داده های خود نسخه پشتیبان تهیه کنید ، در صورت رمزگذاری مطمئن شوید که از کلیدهای رمزنگاری به همراه داده خود نسخه پشتیبان تهیه کنید.",
    "This is the final warning: Do you really want to enable encryption?" : "این آخرین اخطار است: آیا می‌خواهید رمزگذاری را فعال کنید ؟",
    "Submit" : "ارسال",
    "Rename group" : "Rename group",
    "Current password" : "گذرواژه کنونی",
    "New password" : "گذرواژه جدید",
    "Change password" : "تغییر گذرواژه",
    "Choose your profile picture" : "عکس نمایهٔ خود را انتخاب کنید",
    "Please select a valid png or jpg file" : "لطفاً یک فایل png یا jpg معتبر انتخاب کنید",
    "Error setting profile picture" : "خطا در تنظیم عکس نمایه",
    "Error cropping profile picture" : "خطا در برش عکس نمایه",
    "Error saving profile picture" : "خطا در ذخیره تصویر نمایه",
    "Error removing profile picture" : "خطا در حذف عکس نمایه",
    "Your profile picture" : "نگارهٔ نمایه‌تان",
    "Upload profile picture" : "بارگذاری نگارهٔ نمایه",
    "Choose profile picture from Files" : "تصویر نمایه‌تان را از پرونده‌ها انتخاب کنید",
    "Remove profile picture" : "برداشتن نگارهٔ نمایه",
    "The file must be a PNG or JPG" : "فرمت فایل باید PNG یا JPG باشد",
    "Picture provided by original account" : "نگاره فراهم شده به دست حساب اصلی",
    "Set as profile picture" : "به عنوان عکس نمایه تنظیم کنید",
    "Please note that it can take up to 24 hours for your profile picture to be updated everywhere." : "لطفاً توجه داشته باشید که ممکن است تا 24 ساعت طول بکشد تا عکس نمایه شما در همه جا به روز شود.",
    "Unable to update date of birth" : "ناتوانی در به‌روزرسانی تاریخ تولد",
    "Enter your date of birth" : "تاریخ تولدتان را وارد کنید",
    "You are a member of the following groups:" : "عضوی از گروه‌های زیر هستید:",
    "Your full name" : "Your full name",
    "Unable to update primary email address" : "Unable to update primary email address",
    "Unable to delete additional email address" : "Unable to delete additional email address",
    "No email address set" : "آدرس‌ایمیلی تنظیم نشده است",
    "Email options" : "Email options",
    "Remove primary email" : "Remove primary email",
    "Delete email" : "Delete email",
    "This address is not confirmed" : "This address is not confirmed",
    "Unset as primary email" : "Unset as primary email",
    "Set as primary email" : "Set as primary email",
    "Additional email address {index}" : "Additional email address {index}",
    "Unable to delete primary email address" : "Unable to delete primary email address",
    "Unable to add additional email address" : "Unable to add additional email address",
    "Unable to update additional email address" : "Unable to update additional email address",
    "Primary email for password reset and notifications" : "ایمیل اصلی برای بازیابی رمز عبور و دریافت اعلان ها",
    "Your handle" : "Your handle",
    "Your headline" : "عنوان سرصفحه",
    "No language set" : "زبانی تنظیم نشده است.",
    "Unable to update language" : "Unable to update language",
    "Help translate" : "به ترجمه آن کمک کنید",
    "No locale set" : "تنظیمات locale انجام نشده است",
    "Unable to update locale" : "Unable to update locale",
    "Week starts on {firstDayOfWeek}" : "Week starts on {firstDayOfWeek}",
    "Your city" : "شهر شما",
    "Your organisation" : "نام سازمان",
    "Your phone number" : "شماره تلفن شما",
    "Edit your Profile visibility" : "ویرایش امکان مشاهده پروفایل",
    "The more restrictive setting of either visibility or scope is respected on your Profile. For example, if visibility is set to \"Show to everyone\" and scope is set to \"Private\", \"Private\" is respected." : "ملاک عمل، تنظیمات با محدودیت بالاتر است که اعمال می شوند. برای مثال، اگر \"قابلیت دیده شدن\" در وضعیت \"نمایش برای همه\" تنظیم شده باشد و \"محدوده دیده شدن\" در وضعیت \"خصوصی\" تنظیم شده باشد، تنظیم به وضعیت \"خصوصی\" که محدودیت بیشتری اعمال میکند اعمال خواهد شد.",
    "Unable to update visibility of {displayId}" : "Unable to update visibility of {displayId}",
    "Your role" : "نقش شما",
    "Your website" : "وبسایت شما",
    "Unable to update {property}" : "Unable to update {property}",
    "No {property} set" : "No {property} set",
    "Change scope level of {property}, current scope is {scope}" : "Change scope level of {property}, current scope is {scope}",
    "Unable to update federation scope of the primary {property}" : "Unable to update federation scope of the primary {property}",
    "Unable to update federation scope of additional {property}" : "Unable to update federation scope of additional {property}",
    "Add additional email" : "Add additional email",
    "Add" : "افزودن",
    "Create" : "ایجاد",
    "Change" : "تغییر",
    "Delete" : "حذف",
    "Reshare" : "بازهم‌رسانی",
    "School" : "مدرسه",
    "Default language" : "زبان پیش فرض",
    "Common languages" : "زبانهای رایج",
    "Other languages" : "Other languages",
    "Password change is disabled because the master key is disabled" : "تغییر رمز غیرفعال شده است زیرا کلید اصلی غیرفعال شده است",
    "No accounts" : "حسابی وجود ندارد",
    "Manager" : "Manager",
    "Display name" : "نام نمایشی",
    "Either password or email is required" : "Either password or email is required",
    "Password (required)" : "Password (required)",
    "Email (required)" : "Email (required)",
    "Email" : "ایمیل",
    "Quota" : "سهم",
    "Language" : "زبان",
    "Set default language" : "Set default language",
    "_{userCount} account_::_{userCount} accounts_" : ["{userCount} حساب","{userCount} حساب"],
    "Total rows summary" : "خلاصه کل ردیف ها",
    "Scroll to load more rows" : "Scroll to load more rows",
    "Password or insufficient permissions message" : "Password or insufficient permissions message",
    "Avatar" : "آواتار",
    "Account name" : "نام حساب.",
    "Group admin for" : "مدیر گروه برای",
    "Storage location" : "محل ذخیره سازی",
    "Last login" : "آخرین ورود",
    "Account actions" : "اقدامات حساب",
    "{size} used" : "{size} مورد استفاده",
    "Resend welcome email" : "ارسال ایمیل خوش آمدید",
    "Remote wipe of devices" : "پاک کردن از راه دور دستگاه ها",
    "Wipe {userid}'s devices" : "دستگاه های {userid} را پاک کنید",
    "Wiped {userid}'s devices" : "Wiped {userid}'s devices",
    "Fully delete {userid}'s account including all their personal files, app data, etc." : "حساب {userid} را با تمام پرونده های شخصی ، داده های برنامه و غیره به طور کامل حذف کنید.",
    "Account deletion" : "حذف حساب کاربری",
    "Delete {userid}'s account" : "حساب {userid} را حذف کنید",
    "Display name was successfully changed" : "Display name was successfully changed",
    "Password was successfully changed" : "Password was successfully changed",
    "Email was successfully changed" : "Email was successfully changed",
    "Welcome mail sent!" : "نامه خوش آمديد ارسال شد",
    "Set the language" : "Set the language",
    "Done" : "Done",
    "Edit" : "ویرایش",
    "Visibility" : "Visibility",
    "Show language" : "Show language",
    "Show storage path" : "نمایش مسیر ذخیره سازی",
    "Show last login" : "نمایش آخرین ورود",
    "Sorting" : "مرتب سازی",
    "Send email" : "ارسال ایمیل",
    "Defaults" : "Defaults",
    "Default quota" : "سهمیه پیش فرض",
    "Select default quota" : "سهمیه پیش فرض را انتخاب کنید",
    "Server error while trying to complete WebAuthn device registration" : "Server error while trying to complete WebAuthn device registration",
    "Passwordless authentication requires a secure connection." : "Passwordless authentication requires a secure connection.",
    "Add WebAuthn device" : "Add WebAuthn device",
    "Please authorize your WebAuthn device." : "Please authorize your WebAuthn device.",
    "Unnamed device" : "Unnamed device",
    "Passwordless Authentication" : "Passwordless Authentication",
    "Set up your account for passwordless authentication following the FIDO2 standard." : "Set up your account for passwordless authentication following the FIDO2 standard.",
    "No devices configured." : "No devices configured.",
    "The following devices are configured for your account:" : "The following devices are configured for your account:",
    "Your browser does not support WebAuthn." : "Your browser does not support WebAuthn.",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "تنظیم این سرور برای این مهم است که بتواند ایمیل ارسال کند ، مانند تنظیم مجدد گذرواژه و اعلان ها.",
    "Send mode" : "حالت ارسال",
    "Encryption" : "رمزگذاری",
    "Sendmail mode" : "حالت Sendmail",
    "Disable certificate verification (insecure)" : "غیرفعال کردن تأیید گواهینامه (ناامن)",
    "From address" : "آدرس فرستنده",
    "Domain" : "دامنه",
    "Server address" : "آدرس سرور",
    "Host" : "میزبان",
    "Port" : "درگاه",
    "Authentication" : "احراز هویت",
    "Authentication required" : "احراز هویت مورد نیاز است",
    "Saving…" : "در حال ذخیره",
    "Security & setup warnings" : "اخطارهای نصب و امنیتی",
    "Try again" : "تلاش دوباره",
    "All checks passed." : "تمامی موارد با موفقیت چک شدند.",
    "There are some errors regarding your setup." : "برخی از خطاها در مورد راه اندازی شما وجود دارد",
    "There are some warnings regarding your setup." : "هشدارهایی درباره تنظیم شما وجود دارد.",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "به عنوان مدیر ، می توانید رفتار اشتراک گذاری را تنظیم کنید. لطفا برای اطلاعات بیشتر به اسناد مراجعه کنید.",
    "You need to enable the File sharing App." : "You need to enable the File sharing App.",
    "Apply" : "اعمال",
    "All accounts" : "همهٔ حساب‌ها",
    "Admins" : "مدیران",
    "Location" : "مکان",
    "Profile picture" : "تصویر پروفایل",
    "About" : "درباره",
    "Date of birth" : "تاریخ تولد",
    "Full name" : "نام کامل",
    "Additional email" : "Additional email",
    "Fediverse (e.g. Mastodon)" : "فدیورس (مانند ماستودون)",
    "Headline" : "عنوان",
    "Organisation" : "سازمان",
    "Phone number" : "شماره تلفن",
    "Pronouns" : "ضمایر",
    "Role" : "نقش",
    "Website" : "وب‌ سایت",
    "Profile visibility" : "امکان دیده شدن پروفایل",
    "Locale" : "محل",
    "First day of week" : "نخستین روز هفته",
    "Private" : "خصوصی",
    "Only visible to people matched via phone number integration through Talk on mobile" : "نمایان تنها برای افرادی که با یکپارچگی شماره تلفن از طریق Talk روی تلفن همراه مطابقند",
    "Not available as this property is required for core functionality including file sharing and calendar invitations" : "Not available as this property is required for core functionality including file sharing and calendar invitations",
    "Local" : "محلی",
    "Only visible to people on this instance and guests" : "نمایان تنها برای افراد روی این نمونه و میهانان",
    "Federated" : "همگانی",
    "Only synchronize to trusted servers" : "هم‌گام سازی تنها با کارسازهای مورد اعتماد",
    "Published" : "منتشر شده",
    "Synchronize to trusted servers and the global and public address book" : "هم‌گام سازی با کارسازهای مورد اعتماد و دفترچه نشانی‌های عمومی",
    "Your apps" : "برنامه‌های شما",
    "Active apps" : "برنامه‌های فعال",
    "Disabled apps" : "برنامه‌های غیرفعال",
    "Updates" : "به روز رسانی ها",
    "App bundles" : "بسته های برنامه",
    "Featured apps" : "برنامه‌های برگزیده",
    "Supported apps" : "Supported apps",
    "Show to everyone" : "نمایش به همه",
    "Show to logged in accounts only" : "فقط به حساب‌هایی که وارد شده‌اند نمایش یابد",
    "Hide" : "پنهان کردن",
    "Download and enable" : "بارگیری و فعال سازی",
    "Disable" : "غیرفعال",
    "Allow untested app" : "Allow untested app",
    "The app will be downloaded from the App Store" : "The app will be downloaded from the App Store",
    "Unknown" : "ناشناخته",
    "Never" : "هرگز",
    "An error occurred during the request. Unable to proceed." : "An error occurred during the request. Unable to proceed.",
    "Error: This app cannot be enabled because it makes the server unstable" : "Error: This app cannot be enabled because it makes the server unstable",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "برنامه فعال شده است اما باید به روز شود. شما پس از 5 ثانیه به صفحه بروزرسانی هدایت می شوید.",
    "Do you really want to wipe your data from this device?" : "واقعاً می خواهید داده‌هایتان را از این افزاره بزدایید؟",
    "Confirm wipe" : "تأیید زودن",
    "Error while wiping the device with the token" : "هنگام پاک کردن وسیله با نشانه خطا رخ داد",
    "Error while updating device token name" : "هنگام بروزرسانی نام کد وسیله خطایی رخ داد",
    "Error while updating device token scope" : "هنگام بروزرسانی دامنه توکن وسیله خطایی رخ داد",
    "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
    "Error" : "خطا",
    "Forum" : "انجمن",
    "Nextcloud help & privacy resources" : "منابع راهنما و حریم شخصی نکست‌کلود",
    "Legal notice" : "توصیهٔ حقوقی",
    "Privacy policy" : "سیاست محرمانگی",
    "Reasons to use Nextcloud in your organization" : "دلایلی برای استفاده از نکست‌کلود در سازمان شما",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "توسعه یافته توسط {communityopen} انجمن نکست کلود {linkclose}، {githubopen} کد منبع {linkclose} تحت مجوز {licenseopen}AGPL{linkclose}است. ",
    "Like our Facebook page" : "پسندیدن صفحه فیس بوک ما",
    "Follow us on Mastodon" : "ما را در ماستودون دنبال کنید",
    "Check out our blog" : "وبلاگ ما را بررسی کنید",
    "Subscribe to our newsletter" : "مشترک شدن در خبرنامه ما",
    "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "This community release of Nextcloud is unsupported and instant notifications are unavailable.",
    "Open documentation" : "بازکردن مستند",
    "Use a second factor besides your password to increase security for your account." : "برای افزایش امنیت حساب کاربری خود ، از یک عامل دوم علاوه بر رمز عبور خود استفاده کنید.",
    "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication.",
    "Very weak password" : "رمز عبور بسیار ضعیف",
    "Weak password" : "رمز عبور ضعیف",
    "So-so password" : "رمز عبور متوسط",
    "Good password" : "رمز عبور خوب",
    "Strong password" : "رمز عبور قوی",
    "Group list is empty" : "سیاههٔ گروه‌ها خالیست",
    "Unable to retrieve the group list" : "ناتوان در گرفتن سیاهٔ گروه‌ها",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداقل دارای نسخه بعدی نکست کلود است. این یک خطا در آینده خواهد بود.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "این برنامه حداکثر نسخه نکست کلود اختصاصی ندارد. این یک خطا در آینده خواهد بود.",
    "_{userCount} account …_::_{userCount} accounts …_" : ["{userCount} حساب ...","{userCount} حساب ..."],
    "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "در صورت گم شدن دستگاه یا خارج شدن از سازمان ، می توانید داده های نکست کلود را از راه دور از بین همه دستگاه های مرتبط با  {userid} آن پاک کنید. فقط در صورت اتصال دستگاه ها به اینترنت کار می کند.",
    "Adding your device …" : "Adding your device …",
    "Sending…" : "در حال ارسال",
    "Email sent" : "ایمیل ارسال شد",
    "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "این برنامه مطابق با نسخه نکست کلود شما مشخص نشده است. اگر ادامه بدهید همچنان می توانید برنامه را نصب کنید. توجه داشته باشید که برنامه ممکن است مطابق آنچه انتظار می رود کار نکند.",
    "None/STARTTLS" : "None/STARTTLS",
    "SSL" : "SSL",
    "Credentials" : "اعتبارهای",
    "SMTP Password" : "رمز عبور SMTP",
    "Save" : "ذخیره",
    "Test and verify email settings" : "Test and verify email settings",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "برای امنیت و عملکرد نمونه شما، مهم است که همه چیز به درستی پیکربندی شده باشد. برای کمک به شما در این مورد ، ما برخی از بررسی های خودکار را انجام می دهیم. لطفا برای اطلاعات بیشتر به مستندات مرتبط مراجعه کنید.",
    "Checking for system and security issues." : "بررسی مشکلات سیستم و امنیت.",
    "Please double check the <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">installation guides ↗</a>, and check for any errors or warnings in the <a href=\"%2$s\">log</a>." : "لطفاً <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%1$s\">راهنماهای نصب</a> را مجددا مرور کرده و هرگونه خطا یا هشدار را در <a href=\"%2$s\">گزارشات log </a> بررسی کنید.",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "امنیت نکست کلود خود را در مورد <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">اسکن امنیتی ما ↗ </a>بررسی کنید"
},
"nplurals=2; plural=(n > 1);");
